@@ -394,46 +394,48 @@ eigs_sym <- function(A, NEig=1, which="LA", targetShifts=NULL, tol=1e-6,
 
 .getEigsErrorMsg <- function(n) {
    l <- list(
-      "0"= "success",
-      "1"= "reported only amount of required memory",
-      "-1"= "failed in allocating int or real workspace",
-      "-2"= "malloc failed in allocating a permutation integer array",
-      "-3"= "main_iter() encountered problem; the calling stack of the functions where the error occurred was printed in 'stderr'",
-      "-4"= "argument 'primme' is NULL",
-      "-5"= "'n' < 0 or 'nLocal' < 0 or 'nLocal' > 'n'",
-      "-6"= "'numProcs' < 1",
-      "-7"= "'matrixMatvec' is NULL",
-      "-8"= "'applyPreconditioner' is NULL and 'precondition' is not NULL",
-      "-9"= "'not used",
-      "-10"= "'numEvals' > 'n'",
-      "-11"= "'numEvals' < 0",
-      "-12"= "'eps' > 0 and 'eps' < machine precision",
-      "-13"= "'target' is not properly defined",
-      "-14"= "'target' is one of 'primme_largest_abs', 'primme_closest_geq', 'primme_closest_leq' or 'primme_closest_abs' but 'numTargetShifts' <= 0 (no shifts)",
-      "-15"= "'target' is one of 'primme_largest_abs', 'primme_closest_geq', 'primme_closest_leq' or 'primme_closest_abs' but 'targetShifts' is NULL  (no shifts array)",
-      "-16"= "'numOrthoConst' < 0 or 'numOrthoConst' > 'n'. (no free dimensions left)",
-      "-17"= "'maxBasisSize' < 2",
-      "-18"= "'minRestartSize' < 0 or 'minRestartSize' shouldn't be zero",
-      "-19"= "'maxBlockSize' < 0 or 'maxBlockSize' shouldn't be zero",
-      "-20"= "'maxPrevRetain' < 0",
-      "-21"= "'scheme' is not one of *primme_thick* or *primme_dtr*",
-      "-22"= "'initSize' < 0",
-      "-23"= "'locking' == 0 and 'initSize' > 'maxBasisSize'",
-      "-24"= "'locking' and 'initSize' > 'numEvals'",
-      "-25"= "'maxPrevRetain' + 'minRestartSize' >= 'maxBasisSize'",
-      "-26"= "'minRestartSize' >= 'n'",
-      "-27"= "'printLevel' < 0 or 'printLevel' > 5",
-      "-28"= "'convTest' is not one of 'primme_full_LTolerance', 'primme_decreasing_LTolerance', 'primme_adaptive_ETolerance' or 'primme_adaptive'",
-      "-29"= "'convTest' == 'primme_decreasing_LTolerance' and 'relTolBase' <= 1",
-      "-30"= "'evals' is NULL, but not 'evecs' and 'resNorms'",
-      "-31"= "'evecs' is NULL, but not 'evals' and 'resNorms'",
-      "-32"= "'resNorms' is NULL, but not 'evecs' and 'evals'",
-      "-33"= "'locking' == 0 and 'minRestartSize' < 'numEvals'",
-      "-34"= "'ldevecs' is less than 'nLocal'",
-      "-35"= "'ldOPs' is non-zero and less than 'nLocal'",
-      "-36"= "not enough memory for realWork",
-      "-37"= "not enough memory for intWork",
-      "-38"= "'locking' == 0 and 'target' is 'primme_closest_leq' or 'primme_closet_geq'");
+     "0"  = "success",
+     "-1" = "unexpected internal error; please consider to set 'printLevel' to a value larger than 0 to see the call stack and to report these errors because they may be bugs",
+     "-2" = "memory allocation failure",
+     "-3" = "maximum iterations or matvecs reached",
+     "-4" = "argument 'primme' is NULL",
+     "-5" = "'n' < 0 or 'nLocal' < 0 or 'nLocal' > 'n'",
+     "-6" = "'numProcs' < 1",
+     "-7" = "'matrixMatvec' is NULL",
+     "-8" = "'applyPreconditioner' is NULL and 'precondition' is not NULL",
+     "-9" = "'not used",
+     "-10"= "'numEvals' > 'n'",
+     "-11"= "'numEvals' < 0",
+     "-12"= "'eps' > 0 and 'eps' < machine precision",
+     "-13"= "'target' is not properly defined",
+     "-14"= "'target' is one of 'primme_largest_abs', 'primme_closest_geq', 'primme_closest_leq' or 'primme_closest_abs' but 'numTargetShifts' <= 0 (no shifts)",
+     "-15"= "'target' is one of 'primme_largest_abs', 'primme_closest_geq', 'primme_closest_leq' or 'primme_closest_abs' but 'targetShifts' is NULL  (no shifts array)",
+     "-16"= "'numOrthoConst' < 0 or 'numOrthoConst' > 'n'. (no free dimensions left)",
+     "-17"= "'maxBasisSize' < 2",
+     "-18"= "'minRestartSize' < 0 or 'minRestartSize' shouldn't be zero",
+     "-19"= "'maxBlockSize' < 0 or 'maxBlockSize' shouldn't be zero",
+     "-20"= "'maxPrevRetain' < 0",
+     "-21"= "'scheme' is not one of *primme_thick* or *primme_dtr*",
+     "-22"= "'initSize' < 0",
+     "-23"= "'locking' == 0 and 'initSize' > 'maxBasisSize'",
+     "-24"= "'locking' and 'initSize' > 'numEvals'",
+     "-25"= "'maxPrevRetain' + 'minRestartSize' >= 'maxBasisSize'",
+     "-26"= "'minRestartSize' >= 'n'",
+     "-27"= "'printLevel' < 0 or 'printLevel' > 5",
+     "-28"= "'convTest' is not one of 'primme_full_LTolerance', 'primme_decreasing_LTolerance', 'primme_adaptive_ETolerance' or 'primme_adaptive'",
+     "-29"= "'convTest' == 'primme_decreasing_LTolerance' and 'relTolBase' <= 1",
+     "-30"= "'evals' is NULL",
+     "-31"= "'evecs' is NULL",
+     "-32"= "'resNorms' is NULL",
+     "-33"= "'locking' == 0 and 'minRestartSize' < 'numEvals'",
+     "-34"= "'ldevecs' is less than 'nLocal'",
+     "-35"= "'ldOPs' is non-zero and less than 'nLocal'",
+     "-38"= "'locking' == 0 and 'target' is 'primme_closest_leq' or 'primme_closet_geq'",
+     "-40"= "some LAPACK function performing a factorization returned an error code; set 'printLevel' > 0 to see the error code and the call stack",
+     "-41"= "error happened at the matvec or applying the preconditioner",
+     "-42"= "the matrix provided in 'lock' is not full rank",
+     "-43"= "parallel failure",
+     "-44"= "unavailable functionality; PRIMME was not compiled with support for the requesting precision or for GPUs");
    l[[as.character(n)]];
 }
 
