@@ -390,10 +390,9 @@ svds <- function(A, NSvals, which="L", tol=1e-6, u0=NULL, v0=NULL,
 .getSvdsErrorMsg <- function(n) {
    l <- list(
       "0" = "success",
-      "1" = "reported only amount of required memory",
-      "-1" = "failed in allocating int or real workspace",
-      "-2" = "malloc failed in allocating a permutation integer array",
-      "-3" = "main_iter() encountered problem; the calling stack of the functions where the error occurred was printed in 'stderr'",
+      "-1" = "unexpected internal error; please consider to set 'printLevel' to a value larger than 0 to see the call stack and to report these errors because they may be bugs",
+      "-2" = "memory allocation failure",
+      "-3" = "maximum iterations or matvecs reached",
       "-4" = "primme_svds is NULL",
       "-5" = "Wrong value for m or n or mLocal or nLocal",
       "-6" = "Wrong value for numProcs",
@@ -409,8 +408,11 @@ svds <- function(A, NSvals, which="L", tol=1e-6, u0=NULL, v0=NULL,
       "-17" = "svals is not set",
       "-18" = "svecs is not set",
       "-19" = "resNorms is not set",
-      "-20" = "not enough memory for realWork",
-      "-21" = "not enough memory for intWork");
+      "-40" = "some LAPACK function performing a factorization returned an error code; set 'printLevel' > 0 to see the error code and the call stack",
+      "-41" = "error happened at the matvec or applying the preconditioner",
+      "-42" = "the matrix provided in 'lock' is not full rank",
+      "-43" = "parallel failure",
+      "-44" = "unavailable functionality; PRIMME was not compiled with support for the requesting precision or for GPUs");
    if (n >= -100)
       l[[as.character(n)]]
    else if (n >= -200)
