@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2017, College of William & Mary
+ * Copyright (c) 2018, College of William & Mary
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -29,9 +29,7 @@
  *******************************************************************************
  * File: numerical_private.h
  *
- * Purpose - Contains definitions and prototypes for exclusive use with 
- *           numerical.c.  There are various definitions for use with Sun,
- *           IBM, and Cray.
+ * Purpose - Contains definitions and prototypes of BLAS and LAPACK functions.
  *
  ******************************************************************************/
 
@@ -67,82 +65,44 @@
 #  define PRIMME_BLAS_SUFFIX
 #endif
 
-#ifndef NUM_CRAY
+#define LAPACK(X) FORTRAN_FUNCTION(CONCAT(X,PRIMME_BLAS_SUFFIX))
 
-#define SET_LAPACK_SUFFIX(X) FORTRAN_FUNCTION(CONCAT(X,PRIMME_BLAS_SUFFIX))
+#define XCOPY     LAPACK(ARITH(hcopy , kcopy , scopy , ccopy , dcopy , zcopy , , ))
+#define XSWAP     LAPACK(ARITH(hswap , kswap , sswap , cswap , dswap , zswap , , ))
+#define XGEMM     LAPACK(ARITH(hgemm , kgemm , sgemm , cgemm , dgemm , zgemm , , ))
+#define XTRMM     LAPACK(ARITH(htrmm , ktrmm , strmm , ctrmm , dtrmm , ztrmm , , ))
+#define XTRSM     LAPACK(ARITH(htrsm , ktrsm , strsm , ctrsm , dtrsm , ztrsm , , ))
+#define XHEMM     LAPACK(ARITH(hsymm , khemm , ssymm , chemm , dsymm , zhemm , , ))
+#define XHEMV     LAPACK(ARITH(hsymv , khemv , ssymv , chemv , dsymv , zhemv , , ))
+#define XAXPY     LAPACK(ARITH(haxpy , kaxpy , saxpy , caxpy , daxpy , zaxpy , , ))
+#define XGEMV     LAPACK(ARITH(hgemv , kgemv , sgemv , cgemv , dgemv , zgemv , , ))
+#define XDOT      LAPACK(ARITH(hdot  ,       , sdot  ,       , ddot  ,       , , ))
+#define XSCAL     LAPACK(ARITH(hscal , kscal , sscal , cscal , dscal , zscal , , ))
+#define XLARNV    LAPACK(ARITH(hlarnv, klarnv, slarnv, clarnv, dlarnv, zlarnv, , ))
+#define XHEEV     LAPACK(ARITH(hsyev , kheev , ssyev , cheev , dsyev , zheev , , ))
+#define XHEEVX    LAPACK(ARITH(hsyevx, kheevx, ssyevx, cheevx, dsyevx, zheevx, , ))
+#define XGEES     LAPACK(ARITH(hgees , kgees , sgees , cgees , dgees , zgees , , ))
+#define XHEGV     LAPACK(ARITH(hsygv , khegv , ssygv , chegv , dsygv , zhegv , , ))
+#define XGESV     LAPACK(ARITH(hgesv , kgesv , sgesv , cgesv , dgesv , zgesv , , ))
+#define XHEGVX    LAPACK(ARITH(hsygvx, khegvx, ssygvx, chegvx, dsygvx, zhegvx, , ))
+#define XGESVD    LAPACK(ARITH(hgesvd, kgesvd, sgesvd, cgesvd, dgesvd, zgesvd, , ))
+#define XHETRF    LAPACK(ARITH(hsytrf, khetrf, ssytrf, chetrf, dsytrf, zhetrf, , ))
+#define XHETRS    LAPACK(ARITH(hsytrs, khetrs, ssytrs, chetrs, dsytrs, zhetrs, , ))
+#define XPOTRF    LAPACK(ARITH(hpotrf, kpotrf, spotrf, cpotrf, dpotrf, zpotrf, , ))
+#define XGETRF    LAPACK(ARITH(hgetrf, kgetrf, sgetrf, cgetrf, dgetrf, zgetrf, , ))
+#define XGETRS    LAPACK(ARITH(hgetrs, kgetrs, sgetrs, cgetrs, dgetrs, zgetrs, , ))
 
-#ifdef USE_DOUBLE
-#  define LAPACK_FUNCTION(S,C,D,Z) SET_LAPACK_SUFFIX(D)
-#elif defined(USE_DOUBLECOMPLEX)
-#  define LAPACK_FUNCTION(S,C,D,Z) SET_LAPACK_SUFFIX(Z)
-#elif defined(USE_FLOAT)
-#  define LAPACK_FUNCTION(S,C,D,Z) SET_LAPACK_SUFFIX(S)
-#elif defined(USE_FLOATCOMPLEX)
-#  define LAPACK_FUNCTION(S,C,D,Z) SET_LAPACK_SUFFIX(C)
-#endif
+#define STRING const char * 
 
-#define XCOPY     LAPACK_FUNCTION(scopy , ccopy , dcopy , zcopy )   
-#define XSWAP     LAPACK_FUNCTION(sswap , cswap , dswap , zswap )
-#define XGEMM     LAPACK_FUNCTION(sgemm , cgemm , dgemm , zgemm )
-#define XTRMM     LAPACK_FUNCTION(strmm , ctrmm , dtrmm , ztrmm )
-#define XTRSM     LAPACK_FUNCTION(strsm , ctrsm , dtrsm , ztrsm )
-#define XHEMM     LAPACK_FUNCTION(ssymm , chemm , dsymm , zhemm )
-#define XHEMV     LAPACK_FUNCTION(ssymv , chemv , dsymv , zhemv )
-#define XAXPY     LAPACK_FUNCTION(saxpy , caxpy , daxpy , zaxpy )
-#define XGEMV     LAPACK_FUNCTION(sgemv , cgemv , dgemv , zgemv )
-#define XDOT      LAPACK_FUNCTION(sdot  ,       , ddot  ,       )
-#define XSCAL     LAPACK_FUNCTION(sscal , cscal , dscal , zscal )
-#define XLARNV    LAPACK_FUNCTION(slarnv, clarnv, dlarnv, zlarnv)
-#define XHEEV     LAPACK_FUNCTION(ssyev , cheev , dsyev , zheev )
-#define XHEEVX    LAPACK_FUNCTION(ssyevx, cheevx, dsyevx, zheevx)
-#define XHEGV     LAPACK_FUNCTION(ssygv , chegv , dsygv , zhegv )
-#define XHEGVX    LAPACK_FUNCTION(ssygvx, chegvx, dsygvx, zhegvx)
-#define XGESVD    LAPACK_FUNCTION(sgesvd, cgesvd, dgesvd, zgesvd)
-#define XHETRF    LAPACK_FUNCTION(ssytrf, chetrf, dsytrf, zhetrf)
-#define XHETRS    LAPACK_FUNCTION(ssytrs, chetrs, dsytrs, zhetrs)
-#define XGESV     LAPACK_FUNCTION(sgesv , cgesv , dgesv , zgesv )
+#endif /* NUMERICAL_PRIVATE_H */
 
-#else /* NUM_CRAY */
 
-#include <fortran.h>
-#include <string.h>
-
-#ifdef USE_DOUBLE
-#  define LAPACK_FUNCTION(D,Z) D
-#elif defined(USE_DOUBLECOMPLEX)
-#  define LAPACK_FUNCTION(D,Z) Z
-#endif
-
-#define XCOPY  LAPACK_FUNCTION(SCOPY  , zcopy )
-#define XSWAP  LAPACK_FUNCTION(SSWAP  , zswap )
-#define XGEMM  LAPACK_FUNCTION(SGEMM  , zgemm )
-#define XTRMM  LAPACK_FUNCTION(STRMM  , ztrmm )
-#define XTRSM  LAPACK_FUNCTION(STRSM  , ztrsm )
-#define XSYMM  LAPACK_FUNCTION(DSYMM  , zhemm )
-#define XSYMV  LAPACK_FUNCTION(DSYMV  , zhemv )
-#define XAXPY  LAPACK_FUNCTION(SAXPY  , zaxpy )
-#define XGEMV  LAPACK_FUNCTION(SGEMV  , zgemv )
-#define XDOT   LAPACK_FUNCTION(SDOT   ,       )
-#define XSCAL  LAPACK_FUNCTION(SSCAL  , zscal )
-#define XLARNV LAPACK_FUNCTION(SLARNV ,       )
-#define XHEEV  LAPACK_FUNCTION(SSYEV  , zheev )
-#define XHEEVX LAPACK_FUNCTION(SSYEVX , zheevx)
-#define XGESVD LAPACK_FUNCTION(SGESVD , zhetrf)
-#define XSYTRF LAPACK_FUNCTION(SSYTRF , zgesvd)
-#define XSYTRS LAPACK_FUNCTION(SSYTRS , zhetrs)
-#define XGESV  LAPACK_FUNCTION(SGESV  , zgesv )
-
-#endif /* NUM_CRAY */
+#if (!defined(USE_HALF) && !defined(USE_HALFCOMPLEX)) || defined(BLASLAPACK_WITH_HALF)
 
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
 
-#ifndef NUM_CRAY
-#  define STRING const char * 
-#else
-#  define STRING _fcd
-#endif
 
 void XCOPY(PRIMME_BLASINT *n, SCALAR *x, PRIMME_BLASINT *incx, SCALAR *y, PRIMME_BLASINT *incy);
 void XSWAP(PRIMME_BLASINT *n, SCALAR *x, PRIMME_BLASINT *incx, SCALAR *y, PRIMME_BLASINT *incy);
@@ -163,18 +123,22 @@ void XGESVD(STRING jobu, STRING jobvt, PRIMME_BLASINT *m, PRIMME_BLASINT *n, SCA
 #else
 void XHEEV(STRING jobz, STRING uplo, PRIMME_BLASINT *n, SCALAR *a, PRIMME_BLASINT *lda, REAL *w, SCALAR *work, PRIMME_BLASINT *ldwork, REAL *rwork, PRIMME_BLASINT *info);
 void XHEEVX(STRING jobz, STRING range, STRING uplo, PRIMME_BLASINT *n, SCALAR *a, PRIMME_BLASINT *lda, REAL *vl, REAL *vu, PRIMME_BLASINT *il, PRIMME_BLASINT *iu, REAL *abstol, PRIMME_BLASINT *m,  REAL *w, SCALAR *z, PRIMME_BLASINT *ldz, SCALAR *work, PRIMME_BLASINT *ldwork, REAL *rwork, PRIMME_BLASINT *iwork, PRIMME_BLASINT *ifail, PRIMME_BLASINT *info);
+void XGEES(STRING jobvs, STRING uplo, void *, PRIMME_BLASINT *n, SCALAR *a, PRIMME_BLASINT *lda, PRIMME_BLASINT *sdim, SCALAR *w, SCALAR *vs, PRIMME_BLASINT *ldvs, SCALAR *work, PRIMME_BLASINT *ldwork, REAL *rwork, PRIMME_BLASINT *bwork, PRIMME_BLASINT *info);
 void XHEGV(PRIMME_BLASINT *itype, STRING jobz, STRING uplo, PRIMME_BLASINT *n, SCALAR *a, PRIMME_BLASINT *lda, SCALAR *b, PRIMME_BLASINT *ldb, REAL *w, SCALAR *work, PRIMME_BLASINT *ldwork, REAL *rwork, PRIMME_BLASINT *info);
 void XHEGVX(PRIMME_BLASINT *itype, STRING jobz, STRING range, STRING uplo, PRIMME_BLASINT *n, SCALAR *a, PRIMME_BLASINT *lda, SCALAR *b, PRIMME_BLASINT *ldb, REAL *vl, REAL *vu, PRIMME_BLASINT *il, PRIMME_BLASINT *iu, REAL *abstol, PRIMME_BLASINT *m,  REAL *w, SCALAR *z, PRIMME_BLASINT *ldz, SCALAR *work, PRIMME_BLASINT *ldwork, REAL *rwork, PRIMME_BLASINT *iwork, PRIMME_BLASINT *ifail, PRIMME_BLASINT *info);
 void XGESVD(STRING jobu, STRING jobvt, PRIMME_BLASINT *m, PRIMME_BLASINT *n, SCALAR *a, PRIMME_BLASINT *lda, REAL *s, SCALAR *u, PRIMME_BLASINT *ldu, SCALAR *vt, PRIMME_BLASINT *ldvt, SCALAR *work, PRIMME_BLASINT *ldwork, REAL *rwork, PRIMME_BLASINT *info);
 #endif
+void XGESV(PRIMME_BLASINT *n, PRIMME_BLASINT *nrhs, SCALAR *a, PRIMME_BLASINT *lda, PRIMME_BLASINT *ipiv, SCALAR *b, PRIMME_BLASINT *ldb, PRIMME_BLASINT *info);
 void XSCAL(PRIMME_BLASINT *n, SCALAR *alpha, SCALAR *x, PRIMME_BLASINT *incx);
 void XLARNV(PRIMME_BLASINT *idist, PRIMME_BLASINT *iseed, PRIMME_BLASINT *n, SCALAR *x);
 void XHETRF(STRING uplo, PRIMME_BLASINT *n, SCALAR *a, PRIMME_BLASINT *lda, PRIMME_BLASINT *ipivot, SCALAR *work, PRIMME_BLASINT *ldwork, PRIMME_BLASINT *info);
 void XHETRS(STRING uplo, PRIMME_BLASINT *n, PRIMME_BLASINT *nrhs, SCALAR *a, PRIMME_BLASINT *lda, PRIMME_BLASINT *ipivot, SCALAR *b, PRIMME_BLASINT *ldb, PRIMME_BLASINT *info);
-void XGESV(PRIMME_BLASINT *n, PRIMME_BLASINT *nrhs, SCALAR *a, PRIMME_BLASINT *lda, PRIMME_BLASINT *ipivot, SCALAR *b, PRIMME_BLASINT *ldb, PRIMME_BLASINT *info);
+void XPOTRF(STRING uplo, PRIMME_BLASINT *n, SCALAR *a, PRIMME_BLASINT *lda, PRIMME_BLASINT *info);
+void XGETRF(PRIMME_BLASINT *m, PRIMME_BLASINT *n, SCALAR *a, PRIMME_BLASINT *lda, PRIMME_BLASINT *ipivot, PRIMME_BLASINT *info);
+void XGETRS(STRING trans, PRIMME_BLASINT *n, PRIMME_BLASINT *nrhs, SCALAR *a, PRIMME_BLASINT *lda, PRIMME_BLASINT *ipivot, SCALAR *b, PRIMME_BLASINT *ldb, PRIMME_BLASINT *info);
 
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
 
-#endif /* NUMERICAL_PRIVATE_H */
+#endif /* (!defined(USE_HALF) && !defined(USE_HALFCOMPLEX)) || defined(BLASLAPACK_WITH_HALF) */
